@@ -672,6 +672,16 @@ void FolderModel::addDragImage(QDrag *drag, int x, int y)
 }
 
 void FolderModel::dragSelected(int x, int y)
+{
+    // Avoid starting a drag synchronously in a mouse handler or interferes with
+    // child event filtering in parent items (and thus e.g. press-and-hold hand-
+    // ling in a containment).
+    QMetaObject::invokeMethod(this, "dragSelectedInternal", Qt::QueuedConnection,
+        Q_ARG(int, x),
+        Q_ARG(int, y));
+}
+
+void FolderModel::dragSelectedInternal(int x, int y)
 {
     if (!m_viewAdapter || !m_selectionModel->hasSelection()) {
         return;
@@ -751,7 +761,7 @@ void FolderModel::drop(QQuickItem *target, QObject* dropEvent, int row)
             QDBusMessage::createMethodCall(remoteDBusClient, remoteDBusPath,
                                             QStringLiteral("org.kde.ark.DndExtract"),
                                             QStringLiteral("extractSelectedFilesTo"));
-        message.setArguments(QVariantList() << m_dirModel->dirLister()->url().adjusted(QUrl::PreferLocalFile));
+        message.setArguments(QVariantList() << m_dirModel->dirLister()->url().adjusted(QUrl::PreferLocalFile).toString());
 
         QDBusConnection::sessionBus().call(message);
 
